┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/kitemviews/kfileitemmodel.h
diff options
context:
space:
mode:
authorVishesh Handa <[email protected]>2014-02-06 20:29:09 +0100
committerVishesh Handa <[email protected]>2014-02-06 20:29:09 +0100
commit64afe7b22622f79b34aafd54501b08120ab2fc5c (patch)
tree125752b2bc33c5e9db84f197dced5d61a7d46e94 /src/kitemviews/kfileitemmodel.h
parent2c20502c346d975bff854567c038bf0b78c3b857 (diff)
Port Dolphin to Baloo
Nepomuk is being replaced with Baloo
Diffstat (limited to 'src/kitemviews/kfileitemmodel.h')
-rw-r--r--src/kitemviews/kfileitemmodel.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/kitemviews/kfileitemmodel.h b/src/kitemviews/kfileitemmodel.h
index 022429023..15f4b67d3 100644
--- a/src/kitemviews/kfileitemmodel.h
+++ b/src/kitemviews/kfileitemmodel.h
@@ -187,14 +187,14 @@ public:
{ QByteArray role;
QString translation;
QString group;
- bool requiresNepomuk;
+ bool requiresBaloo;
bool requiresIndexer;
};
/**
* @return Provides static information for all available roles that
* are supported by KFileItemModel. Some roles can only be
* determined if Nepomuk is enabled and/or the Nepomuk
* indexing is enabled.
*/
static QList<RoleInfo> rolesInformation();
@@ -287,7 +287,7 @@ private:
// User visible roles:
NoRole, NameRole, SizeRole, DateRole, PermissionsRole, OwnerRole,
GroupRole, TypeRole, DestinationRole, PathRole,
// User visible roles available with Nepomuk:
CommentRole, TagsRole, RatingRole, ImageSizeRole, OrientationRole,
WordCountRole, LineCountRole, ArtistRole, AlbumRole, DurationRole, TrackRole,
CopiedFromRole,
@@ -432,7 +432,7 @@ private:
const char* const roleTranslation;
const char* const groupTranslationContext;
const char* const groupTranslation;
- const bool requiresNepomuk;
+ const bool requiresBaloo;
const bool requiresIndexer;
};
@@ -187,14 +187,14 @@ public:
* @return Provides static information for all available roles that
* are supported by KFileItemModel. Some roles can only be
- * determined if Nepomuk is enabled and/or the Nepomuk
+ * determined if Baloo is enabled and/or the Baloo
* indexing is enabled.
*/
@@ -287,7 +287,7 @@ private:
NoRole, NameRole, SizeRole, DateRole, PermissionsRole, OwnerRole,
GroupRole, TypeRole, DestinationRole, PathRole,
- // User visible roles available with Nepomuk:
+ // User visible roles available with Baloo:
CommentRole, TagsRole, RatingRole, ImageSizeRole, OrientationRole,
WordCountRole, LineCountRole, ArtistRole, AlbumRole, DurationRole, TrackRole,